@@ -109,7 +109,7 @@ class VolCommand(KuroCommand):
             response = response_str[idx:idx + 3]
             self.volume = int(response)
         else:
-            self.valume = None   
+            self.volume = None   
 
 class MutedState(Enum):
     NONE = None
@@ -123,8 +123,10 @@ class MutedCommand(ParameterCommand):
 
     def process_response(self, response):
         super().process_response(response)
-        if self.response_type == ResponseType.NOT_PROCESSED and self.params == None:
-            self.is_muted = MutedState(self.response[1:])    
+        if self.response_type == ResponseType.SUCCESS:
+            self.is_muted =   MutedState(self.response[1:])
+        else:
+            self.is_muted = MutedState.NONE
 
 class ChannelDirection(Enum):
     FORWARD = "FWD"
